package com.ruoyi.ss.riskInfo.mapper;

import java.util.List;
import com.ruoyi.ss.riskInfo.domain.RiskInfo;
import com.ruoyi.ss.riskInfo.domain.RiskInfoVO;
import com.ruoyi.ss.riskInfo.domain.RiskInfoQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 风控材料Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-25
 */
public interface RiskInfoMapper
{
    /**
     * 查询风控材料
     *
     * @param infoId 风控材料主键
     * @return 风控材料
     */
    public RiskInfoVO selectRiskInfoByInfoId(Long infoId);

    /**
     * 查询风控材料列表
     *
     * @param query 风控材料
     * @return 风控材料集合
     */
    public List<RiskInfoVO> selectRiskInfoList(@Param("query")RiskInfoQuery query);

    /**
     * 新增风控材料
     *
     * @param riskInfo 风控材料
     * @return 结果
     */
    public int insertRiskInfo(RiskInfo riskInfo);

    /**
     * 修改风控材料
     *
     * @param riskInfo 风控材料
     * @return 结果
     */
    public int updateRiskInfo(@Param("data") RiskInfo riskInfo);

    /**
     * 删除风控材料
     *
     * @param infoId 风控材料主键
     * @return 结果
     */
    public int deleteRiskInfoByInfoId(Long infoId);

    /**
     * 批量删除风控材料
     *
     * @param infoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRiskInfoByInfoIds(Long[] infoIds);

    /**
     * 根据查询条件更新数据
     */
    int updateByQuery(@Param("data") RiskInfo data, @Param("query") RiskInfoQuery query);

    /**
     * 查询数量
     */
    int selectCount(@Param("query") RiskInfoQuery query);
}
